@@ -149,23 +149,14 @@ def enable_python_hooks(ij):
                         print(str(view.msp.getAtlas().getName()))
                         if str(view.msp.getAtlas().getName()) == 'Adult Mouse Brain - Allen Brain Atlas V3p1':
                             print('Adult Mouse Brain - Allen Brain Atlas V3p1 detected, installing DeepSlice module')
-                            print('0')
                             BdvScijavaHelper = jimport('sc.fiji.bdvpg.scijava.BdvScijavaHelper')
-                            print('1')
                             from jpype import JImplements, JOverride
-                            print('2')
                             Runnable = jimport('java.lang.Runnable')
-                            print('3')
 
                             class DSPlaceHolder(object):
                                 def __init__(self, ij):
-                                    print('ze temp')
                                     self.temp_folder = prepare_deepslice_temp_folder(self)
-                                    print('alors')
                                     self.ij = ij
-                                    print('heu')
-
-                            print('4')
 
                             @JImplements(Runnable)
                             class ExecuteDeepSlicePython(object):
@@ -185,19 +176,14 @@ def enable_python_hooks(ij):
                                                               "dataset_folder", JString(self.dsp.temp_folder)
                                                               )
 
-                            print('5')
-                            print('ij= '+str(ij))
                             dsplaceholder = DSPlaceHolder(ij)
-                            print('5A')
                             edsp = ExecuteDeepSlicePython(dsplaceholder)
-                            print('5B')
                             bdv_view = view.getBdvh()
-                            print('5C')
 
                             BdvScijavaHelper.addActionToBdvHandleMenu(bdv_view,
                                                                       "Align>ABBA - DeepSlice Registration (Python)", 0,
                                                                       edsp)
-                            print('6')
+
 
     @JImplements(Supplier)
     class IPyWidgetCommandPreprocessorSupplier(object):
@@ -210,7 +196,6 @@ def enable_python_hooks(ij):
 
 
 def prepare_deepslice_temp_folder(self):
-    print('pdtf0')
     if not hasattr(self, '_run_deep_slice'):
         try:
             from abba_python.abba_private.DeepSliceProcessor import \
@@ -224,19 +209,15 @@ def prepare_deepslice_temp_folder(self):
 
         self._run_deep_slice = DeepSliceProcessor()
 
-    print('pdtf1')
     # TODO : fix potential multiple running instance issues
     temp_folder = tempfile.gettempdir() + '/temp/deepslice/'
 
-    print('pdtf2')
     # make sure that the folder exists
     if not os.path.exists(temp_folder):
         os.makedirs(temp_folder)
 
-    print('pdtf3')
     # clean folder : remove all previous files
     for filename in os.listdir(temp_folder):
-        print('pdtf3a')
         file_path = os.path.join(temp_folder, filename)
         try:
             if os.path.isfile(file_path) or os.path.islink(file_path):
@@ -244,9 +225,8 @@ def prepare_deepslice_temp_folder(self):
             # elif os.path.isdir(file_path):
             #    shutil.rmtree(file_path)
         except Exception as e:
-            print('pdtf3error')
             print('Failed to delete %s. Reason: %s' % (file_path, e))
-    print('pdtf4')
+
     # print('Temp folder = '+str(temp_folder))
     return temp_folder
 
@@ -391,7 +371,7 @@ class Abba:
 
             @JOverride
             def run(self):
-                temp_folder = self.abba.prepare_deepslice_temp_folder()
+                temp_folder = prepare_deepslice_temp_folder(self)
                 RegisterSlicesDeepSliceCommand = jimport(
                     'ch.epfl.biop.atlas.aligner.command.RegisterSlicesDeepSliceCommand')
                 # Any missing input parameter will lead to a popup window asking the missing argument to the user
@@ -409,30 +389,41 @@ class Abba:
     def get_bdv_view(self):
         return self.bdv_view
 
-    def prepare_deepslice_temp_folder(self):  # TODO : remove
-        if not hasattr(self, '_run_deep_slice'):
-            from src.abba_python.abba_private.DeepSliceProcessor import DeepSliceProcessor
-            self._run_deep_slice = DeepSliceProcessor()
-
-        # TODO : fix potential multiple running instance issues
-        temp_folder = tempfile.gettempdir() + '/temp/deepslice/'
-
-        # make sure that the folder exists
-        if not os.path.exists(temp_folder):
-            os.makedirs(temp_folder)
-
-        # clean folder : remove all previous files
-        for filename in os.listdir(temp_folder):
-            file_path = os.path.join(temp_folder, filename)
-            try:
-                if os.path.isfile(file_path) or os.path.islink(file_path):
-                    os.unlink(file_path)
-                # elif os.path.isdir(file_path):
-                #    shutil.rmtree(file_path)
-            except Exception as e:
-                print('Failed to delete %s. Reason: %s' % (file_path, e))
-        # print('Temp folder = '+str(temp_folder))
-        return temp_folder
+    # def prepare_deepslice_temp_folder(self):  # TODO : remove
+    #
+    #     if not hasattr(self, '_run_deep_slice'):
+    #         try:
+    #             from abba_python.abba_private.DeepSliceProcessor import \
+    #                 DeepSliceProcessor  # delayed import because the jvm should be set first
+    #         except:
+    #             try:
+    #                 from .abba_private.DeepSliceProcessor import \
+    #                     DeepSliceProcessor  # delayed import because the jvm should be set first
+    #             except:
+    #                 print(
+    #                     "Could not import DeepSliceProcessor because the dev do not understand python modules and submodules.")
+    #
+    #     self._run_deep_slice = DeepSliceProcessor()
+    #
+    #     # TODO : fix potential multiple running instance issues
+    #     temp_folder = tempfile.gettempdir() + '/temp/deepslice/'
+    #
+    #     # make sure that the folder exists
+    #     if not os.path.exists(temp_folder):
+    #         os.makedirs(temp_folder)
+    #
+    #     # clean folder : remove all previous files
+    #     for filename in os.listdir(temp_folder):
+    #         file_path = os.path.join(temp_folder, filename)
+    #         try:
+    #             if os.path.isfile(file_path) or os.path.islink(file_path):
+    #                 os.unlink(file_path)
+    #             # elif os.path.isdir(file_path):
+    #             #    shutil.rmtree(file_path)
+    #         except Exception as e:
+    #             print('Failed to delete %s. Reason: %s' % (file_path, e))
+    #     # print('Temp folder = '+str(temp_folder))
+    #     return temp_folder
 
     # ------------------------ IMPORT
     def import_from_files(self, filepaths, z_location=0, z_increment=0.02, split_rgb=False):
@@ -509,7 +500,7 @@ class Abba:
             print('Deep Slice only support the Allen Brain Atlas CCFv3 in coronal slicing mode')
             return
 
-        temp_folder = self.prepare_deepslice_temp_folder()
+        temp_folder = prepare_deepslice_temp_folder(self)
 
         RegisterSlicesDeepSliceCommand = jimport('ch.epfl.biop.atlas.aligner.command.RegisterSlicesDeepSliceCommand')
 
